@@ -1,6 +1,6 @@
 import logging
 from shutil import rmtree
-from vtypes import is_iterable
+from vxbase.vtypes import is_iterable
 from os import path, remove
 
 
